==> PikaBus-1.0.11-py3-none-any.whl: PikaBus/tools/PikaConstants.py <==
INTENT_COMMAND = 'command'
INTENT_EVENT = 'event'

DATA_KEY_DIRECT_EXCHANGE = 'directExchange'
DATA_KEY_TOPIC_EXCHANGE = 'topicExchange'
DATA_KEY_DIRECT_EXCHANGE_ARGUMENTS = 'directExchangeArguments'
DATA_KEY_TOPIC_EXCHANGE_ARGUMENTS = 'topicExchangeArguments'
DATA_KEY_CONNECTION = 'connection'
DATA_KEY_CHANNEL = 'channel'
DATA_KEY_BUS = 'bus'
DATA_KEY_MESSAGE_HANDLERS = 'messageHandlers'
DATA_KEY_SERIALIZER = 'serializer'
DATA_KEY_ERROR_HANDLER = 'errorHandler'
DATA_KEY_PROPERTY_BUILDER = 'propertyBuilder'
DATA_KEY_INCOMING_MESSAGE = 'incomingMessage'
DATA_KEY_OUTGOING_MESSAGES = 'outgoingMessages'
DATA_KEY_LOGGER = 'logger'

DATA_KEY_BODY = 'body'
DATA_KEY_PAYLOAD = 'payload'
DATA_KEY_LISTENER_QUEUE = 'listeningQueue'
DATA_KEY_TOPIC = 'topic'
DATA_KEY_INTENT = 'intent'
DATA_KEY_HEADERS = 'headers'
DATA_KEY_EXCHANGE = 'exchange'
DATA_KEY_EXCHANGE_ARGUMENTS = 'exchangeArguments'
DATA_KEY_CONTENT_TYPE = 'contentType'
DATA_KEY_EXCEPTION = 'exception'
DATA_KEY_MESSAGE_TYPE = 'messageType'
DATA_KEY_METHOD_FRAME = 'methodFrame'
DATA_KEY_HEADER_FRAME = 'headerFrame'

HEADER_KEY_MESSAGE_ID = 'MessageId'
HEADER_KEY_TIME_SENT = 'TimeSent'
HEADER_KEY_REPLY_TO_ADDRESS = 'ReplyToAddress'
HEADER_KEY_ORIGINATING_ADDRESS = 'OriginatingAddress'
HEADER_KEY_INTENT = 'Intent'
HEADER_KEY_MESSAGE_TYPE = 'MessageType'
HEADER_KEY_CORRELATION_ID = 'CorrelationId'
HEADER_KEY_CONTENT_TYPE = 'ContentType'
HEADER_KEY_ERROR_DETAILS = 'ErrorDetails'
HEADER_KEY_SOURCE_QUEUE = 'SourceQueue'
HEADER_KEY_ERROR_RETRIES = 'ErrorRetries'
HEADER_KEY_DEFERRED_TIME = 'DeferredTime'

==> PikaBus-1.0.14-py3-none-any.whl: PikaBus/tools/PikaConstants.py <==
INTENT_COMMAND = 'command'
INTENT_EVENT = 'event'

DATA_KEY_DIRECT_EXCHANGE = 'directExchange'
DATA_KEY_TOPIC_EXCHANGE = 'topicExchange'
DATA_KEY_DIRECT_EXCHANGE_ARGUMENTS = 'directExchangeArguments'
DATA_KEY_TOPIC_EXCHANGE_ARGUMENTS = 'topicExchangeArguments'
DATA_KEY_CONNECTION = 'connection'
DATA_KEY_CHANNEL = 'channel'
DATA_KEY_BUS = 'bus'
DATA_KEY_MESSAGE_HANDLERS = 'messageHandlers'
DATA_KEY_SERIALIZER = 'serializer'
DATA_KEY_ERROR_HANDLER = 'errorHandler'
DATA_KEY_PROPERTY_BUILDER = 'propertyBuilder'
DATA_KEY_INCOMING_MESSAGE = 'incomingMessage'
DATA_KEY_OUTGOING_MESSAGES = 'outgoingMessages'
DATA_KEY_LOGGER = 'logger'

DATA_KEY_BODY = 'body'
DATA_KEY_PAYLOAD = 'payload'
DATA_KEY_LISTENER_QUEUE = 'listenerQueue'
DATA_KEY_LISTENER_QUEUE_ARGUMENTS = 'listenerQueueArguments'
DATA_KEY_TOPIC = 'topic'
DATA_KEY_INTENT = 'intent'
DATA_KEY_HEADERS = 'headers'
DATA_KEY_EXCHANGE = 'exchange'
DATA_KEY_EXCHANGE_ARGUMENTS = 'exchangeArguments'
DATA_KEY_CONTENT_TYPE = 'contentType'
DATA_KEY_EXCEPTION = 'exception'
DATA_KEY_MESSAGE_TYPE = 'messageType'
DATA_KEY_METHOD_FRAME = 'methodFrame'
DATA_KEY_HEADER_FRAME = 'headerFrame'

HEADER_KEY_MESSAGE_ID = 'MessageId'
HEADER_KEY_TIME_SENT = 'TimeSent'
HEADER_KEY_REPLY_TO_ADDRESS = 'ReplyToAddress'
HEADER_KEY_ORIGINATING_ADDRESS = 'OriginatingAddress'
HEADER_KEY_INTENT = 'Intent'
HEADER_KEY_MESSAGE_TYPE = 'MessageType'
HEADER_KEY_CORRELATION_ID = 'CorrelationId'
HEADER_KEY_CONTENT_TYPE = 'ContentType'
HEADER_KEY_ERROR_DETAILS = 'ErrorDetails'
HEADER_KEY_SOURCE_QUEUE = 'SourceQueue'
HEADER_KEY_ERROR_RETRIES = 'ErrorRetries'
HEADER_KEY_DEFERRED_TIME = 'DeferredTime'
